#
# spec file for package python-service_identity
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oname   service_identity
Name:           python-service_identity
Version:        18.1.0
Release:        3.2.1
Summary:        Service identity verification for pyOpenSSL
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pyca/service_identity
# no tests in upstream tarball
Source:         https://github.com/pyca/service_identity/archive/%{version}.tar.gz
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module idna}
BuildRequires:  %{python_module pyOpenSSL >= 0.14}
BuildRequires:  %{python_module pyasn1-modules}
BuildRequires:  %{python_module pyasn1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs
Requires:       python-cryptography
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Recommends:     python-idna
Recommends:     python-pyOpenSSL
BuildArch:      noarch
%ifpython2
Requires:       python-ipaddress
%endif
%python_subpackages

%description
service_identity aspires to give you all the tools you need for
verifying whether a certificate is valid for the intended purposes.

In the simplest case, this means host name verification. However,
service_identity implements RFC 6125 fully and plans to add other
relevant RFCs too.

%prep
%setup -q -n service-identity-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%{python_sitelib}/%{oname}
%{python_sitelib}/%{oname}-%{version}-py%{py_ver}.egg-info

%changelog
* Fri Jan  3 2020 tchvatal@suse.com
- Format with spec-cleaner
- Upstream seems to rebase the tarball, refetch it
* Fri Mar  1 2019 mimi.vx@gmail.com
- update to 18.1.0
- drop fetch-intersphinx-inventories.sh
- drop local-intersphinx-inventories.patch
- cleanup spec + enable tests
  * pyOpenSSL is optional now if you use service_identity.cryptography.* only.
  * Added support for iPAddress subjectAltNames.
* Mon Feb 25 2019 toddrme2178@gmail.com
- add fetch-intersphinx-inventories.sh to the sources
* Mon Feb  4 2019 hpj@urpla.net
- add local-intersphinx-inventories.patch for generating the docs
  correctly
- add fetch-intersphinx-inventories.sh to fetch the inventories
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Oct  1 2018 bwiedemann@suse.com
- Reduce parallelism of sphinx-build
  to ensure reproducible builds (boo#1102408)
* Tue Sep 25 2018 tchvatal@suse.com
- Drop some SLE11 code that is quite useless today
* Mon Sep 24 2018 ecsos@opensuse.org
- Update to 17.0.0:
  * Deprecations:
  - Since Chrome 58 and Firefox 48 both don’t accept certificates
    that contain only a Common Name, its usage is hereby
    deprecated in service_identity too. We have been raising
    a warning since 16.0.0 and the support will be removed in
    mid-2018 for good.
  * Changes:
  - When service_identity.SubjectAltNameWarning is raised, the
    Common Name of the certificate is now included in the warning
    message. #17
  - Added cryptography.x509 backend for verifying certificates.
    [#18]
  - Wildcards (*) are now only allowed if they are the leftmost
    label in a certificate. This is common practice by all major
    browsers. #19
* Sat Jul  1 2017 okurz@suse.com
- Convert to singlespec
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to 16.0.0:
  * Changes:
    +  Officially support Python 3.5.
    +  service_identity.SubjectAltNameWarning is now raised if the server certicate lacks a proper SubjectAltName. [#9]
    +  Add a __str__ method to VerificationError.
    +  Port from characteristic to its spiritual successor attrs.
  * Backward-incompatible changes:
    +  Python 3.3 and 2.6 aren't supported anymore. They may work by chance but any effort to keep them working has ceased.
    +  pyOpenSSL versions older than 0.14 are not tested anymore. They don't even build with recent OpenSSL versions.
- Update spec file with new upstream package requirements.
* Tue Jul 21 2015 nemysis@gmx.ch
- Change URL
- Use %%{oname} instead of service_identity
- Add BuildRequires for python-Sphinx for Documentation
- Change Description
- Change Documentation add index.html
- Add Man Page
* Thu Jul 16 2015 jacobwinski@gmail.com
- update pkg description to reflect upstream
- rm warnings in description about this pkg being alpha / possibly broken
* Thu Jul 16 2015 jacobwinski@gmail.com
- alphabetize BuildRequires & Requires
- remove no longer needed commented out test fail workaround
* Thu Jul 16 2015 jacobwinski@gmail.com
- update to 14.0.0:
  * update spec file with new requirements per instructions by upstream
  * update spec file comment out no longer needed test fail workaround
  * upstream changes:
    + Switch to year-based version numbers.
    + Port to characteristic 14.0 (get rid of deprecation warnings).
    + Package docs with sdist.
-update to 1.0.0:
  * Backward-incompatible changes:
    + Drop support for Python 3.2. There is no justification to add complexity and unnecessary function calls for a Python version that nobody uses.
  * changes:
    + Move into the Python Cryptography Authority’s GitHub account.
    + Move exceptions into service_identity.exceptions so tracebacks don’t contain private module names.
    + Promoting to stable since Twisted 14.0 is optionally depending on service_identity now.
    + Use characteristic instead of a home-grown solution.
    + idna 0.6 did some backward-incompatible fixes that broke Python 3 support. This has been fixed now therefore service_identity only works with idna 0.6 and later. Unfortunately since idna doesn’t offer version introspection, service_identity can’t warn about it.
* Thu May 15 2014 hpj@urpla.net
- version 0.2: initial build
